# dataset handling

use Test;
BEGIN { plan tests => 7 };
use HTML::Tabulate;
use strict;

# Load result strings
my $test = 't1';
my %result = ();
die "missing data dir t/$test" unless -d "t/$test";
opendir DATADIR, "t/$test" or die "can't open t/$test";
for (readdir DATADIR) {
  next if m/^\./;
  open FILE, "<t/$test/$_" or die "can't read t/$test/$_";
  { 
    local $/ = undef;
    $result{$_} = <FILE>;
  }
  close FILE;
}
close DATADIR;

my $t = HTML::Tabulate->new();

# Simple hashref
my $d = { emp_id => '123', name => 'Fred Flintstone', title => 'CEO' };
ok($t->render($d) eq $result{fred});

# Nested arrayrefs
$d = [ [ '123', 'Fred Flintstone', 'CEO' ] ];
ok($t->render($d) eq $result{fred});
$d = [ [ '123', 'Fred Flintstone', 'CEO' ], [ '456', 'Barney Rubble', 'Lackey' ] ];
ok($t->render($d) eq $result{fredbarney});
$d = [ [ '123', 'Fred Flintstone', 'CEO' ], 
       [ '456', 'Barney Rubble', 'Lackey' ],
       [ '789', 'Wilma Flintstone   ', 'CFO' ], 
       [ '777', 'Betty Rubble', '' ], ];
ok($t->render($d) eq $result{fbwb});

# Nested hashrefs
$d = [ { emp_id => '123', name => 'Fred Flintstone', title => 'CEO' } ];
ok($t->render($d) eq $result{fred});
$d = [ { emp_id => '123', name => 'Fred Flintstone', title => 'CEO' }, 
       { emp_id => '456', name => 'Barney Rubble', title => 'Lackey' }, ];
ok($t->render($d) eq $result{fredbarney});
$d = [ { emp_id => '123', name => 'Fred Flintstone', title => 'CEO' }, 
       { emp_id => '456', name => 'Barney Rubble', title => 'Lackey' },
       { emp_id => '789', name => 'Wilma Flintstone   ', title => 'CFO' },
       { emp_id => '777', name => 'Betty Rubble', title => '' }, ];
ok($t->render($d) eq $result{fbwb});

